@@ -48,6 +48,7 @@ class Package():
 
         logger.debug("Processing Package: " + pkgName)
 
+        logger.debug("Getting JSON package information: " + pkgName)
         try:
             # Here we get the json info page for the package
             page = requests.get(baseUrl + "/pypi/" + pkgName
@@ -64,21 +65,6 @@ class Package():
                             for file in jsonPage['releases'][release]:
                                 self.__fileList.append(file)
 
-            # Here we get the index file for the package
-            page = requests.get(baseUrl + "/simple/" + pkgName)
-            page.raise_for_status()
-            tree = html.fromstring(page.content)
-
-            # Here we get the list of urls to the package file versions to
-            # make into a relative
-            # path to save as our localized index.html for that package
-            a_tags = tree.xpath("//a")
-            for a in a_tags:
-                orig_url = a.get("href")
-                new_url = re.sub(r"http\w*://.*/packages", "../../packages",
-                                 orig_url, 1, re.IGNORECASE)
-                a.set("href", new_url)
-            self.__indexFile = tree
         except requests.ConnectionError as err:
             logger.warning("Connection error while getting json info for"
                            "package " + pkgName + ": {0}".format(err))
@@ -101,6 +87,45 @@ class Package():
             logger.warning("Unknown Error: {}".format(err))
             self.__jsonError = True
 
+        logger.debug("Getting package index file: " + pkgName)
+        try:
+            # Here we get the index file for the package
+            page = requests.get(baseUrl + "/simple/" + pkgName)
+            page.raise_for_status()
+            tree = html.fromstring(page.content)
+
+            # Here we get the list of urls to the package file versions to
+            # make into a relative
+            # path to save as our localized index.html for that package
+            a_tags = tree.xpath("//a")
+            for a in a_tags:
+                orig_url = a.get("href")
+                new_url = re.sub(r"http\w*://.*/packages", "../../packages",
+                                 orig_url, 1, re.IGNORECASE)
+                a.set("href", new_url)
+            self.__indexFile = tree
+        except requests.ConnectionError as err:
+            logger.warning("Connection error while getting index file for"
+                           "package " + pkgName + ": {0}".format(err))
+            self.__jsonError = True
+        except requests.HTTPError as err:
+            logger.warning("HTTP unsuccessful response while "
+                           "getting index file for package "
+                           + pkgName + ": {0}".format(err))
+            self.__jsonError = True
+        except requests.Timeout as err:
+            logger.warning("Timeout error while getting index file for package "
+                           + pkgName + ": {0}".format(err))
+            self.__jsonError = True
+        except requests.TooManyRedirects as err:
+            logger.warning("TooManyRedirects error while "
+                           "getting index file for package "
+                           + pkgName + ": {0}".format(err))
+            self.__jsonError = True
+        except Exception as err:
+            logger.warning("Unknown Error: {}".format(err))
+            self.__jsonError = True
+
         return self.__jsonError
 
     def getFileList(self):
@@ -198,8 +223,8 @@ def parseCommandLine():
     """
     parser = argparse.ArgumentParser(
         description="Script to mirror pypi packages",
-        epilog="If neither '-c' nor '-i' are given, "
-               "packages are read from stdin.")
+        epilog="Note: options -i, -p, and --stdin are mutually "
+        "exclusive")
     parser.add_argument('-m', dest='mirror_tld',
                         default='/tmp/repos',
                         help='Base directory to store'
@@ -226,6 +251,8 @@ def parseCommandLine():
                        'with the -u option')
     group.add_argument('-p', dest='package_name',
                        help='name of package to install')
+    group.add_argument('--stdin', dest='stdin', action='store_true',
+                       help='pull package list from STDIN')
 
     args = parser.parse_args()
 
@@ -822,7 +849,7 @@ def main():
                     + args.package_name)
         pkgs = []
         pkgs.append(args.package_name)
-    elif not sys.stdin.isatty():
+    elif args.stdin:
         logger.info("Grabbing list of packages from stdin...")
         pkgs = sys.stdin.read().split()
 
